@@ -16,7 +16,8 @@
 #' on the similarity structure.
 listStabilityMeasures = function() {
   l = list(
-    list("stabilityDavis", FALSE, FALSE, 0, 1),
+    data.frame(Name = "stabilityDavis", Corrected = FALSE, Adjusted = FALSE,
+      Minimum = 0, Maximum = 1, stringsAsFactors = FALSE),
     list("stabilityDice", FALSE, FALSE, 0, 1),
     list("stabilityHamming", FALSE, FALSE, 0, 1),
     list("stabilityIntersectionCount", TRUE, TRUE, NA, 1),
@@ -30,6 +31,7 @@ listStabilityMeasures = function() {
     list("stabilityNovovicova", FALSE, FALSE, 0, 1),
     list("stabilityOchiai", FALSE, FALSE, 0, 1),
     list("stabilityPhi", TRUE, FALSE, -1, 1),
+    list("stabilitySechidis", FALSE, TRUE, NA, NA),
     list("stabilitySomol", TRUE, FALSE, 0, 1),
     list("stabilityUnadjusted", TRUE, FALSE, -1, 1),
     list("stabilityWald", TRUE, FALSE, "1-p", 1),
@@ -37,7 +39,5 @@ listStabilityMeasures = function() {
     list("stabilityZucknick", FALSE, TRUE, 0, 1)
   )
 
-  l = BBmisc::convertListOfRowsToDataFrame(l, strings.as.factors = FALSE)
-  colnames(l) = c("Name", "Corrected", "Adjusted", "Minimum", "Maximum")
-  return(l)
-}
\ No newline at end of file
+  do.call(rbind, l)
+}
