@@ -11,14 +11,7 @@
 #' Note that this definition slightly differs from its original in order to make it suitable
 #' for arbitrary similarity measures.
 #' @references
-#' * M. Zucknick, S. Richardson, and E. Stronach, "Comparing the
-#' characteristics of gene expression profiles derived by univariate
-#' andmultivariate classification methods", Statistical Applications
-#' in Genetics and Molecular Biology, vol. 7, no. 1, pp. 1-34, 2008.
-#' * A. Bommert, J. Rahnenführer, and M. Lang,
-#' "A multi-criteria approach to find predictive and sparse models with
-#' stable feature selection for high-dimensional data",
-#' Computational and mathematical methods in medicine, 2017.
+#' `r tools::toRd(bibentries[c("Zucknick2008", "Bommert2017")])`
 #' @encoding UTF-8
 #' @md
 #' @examples
@@ -49,15 +42,7 @@ stabilityZucknick = function(features, sim.mat, threshold = 0.9,
 #' Note that this definition slightly differs from its original in order to make it suitable
 #' for arbitrary datasets and similarity measures and applicable in situations with \eqn{|V_i| \neq |V_j|}.
 #' @references
-#' * L. Yu, Y. Han, and M. E. Berens,
-#' "Stable gene selection from microarray data via sample weighting",
-#' IEEE/ACM Transactions on Computational Biology and Bioinformatics,
-#' vol. 9, no. 1, pp. 262-272, 2012.
-#' * M. Zhang, L. Zhang, J. Zou, C. Yao, H. Xiao, Q. Liu, J. Wang, D. Wang,
-#' C. Wang, and Z. Guo,
-#' "Evaluating reproducibility of differential expression discoveries in microarray
-#' studies by considering correlated molecular changes", Bioinformatics,
-#' vol. 25, no. 13, pp. 1662-1668, 2009.
+#' `r tools::toRd(bibentries[c("LeiYu2012", "Zhang2009")])`
 #' @md
 #' @examples
 #' feats = list(1:3, 1:4, 1:5)
@@ -85,14 +70,18 @@ stabilityYu = function(features, sim.mat, threshold = 0.9,
 #' of \eqn{V_i \backslash V_j} on the one side and the features of \eqn{V_j \backslash V_i}
 #' on the other side. Vertices x and y are connected if and only if \eqn{Similarity(x, y)
 #' \geq threshold.}
+#' Requires the package \CRANpkg{igraph}.
+#' @references
+#' `r tools::toRd(bibentries["Bommert2020"])`
+#' @encoding UTF-8
+#' @md
 #' @examples
 #' feats = list(1:3, 1:4, 1:5)
 #' mat = 0.92 ^ abs(outer(1:10, 1:10, "-"))
 #' stabilityIntersectionMBM(features = feats, sim.mat = mat, N = 1000)
 stabilityIntersectionMBM = function(features, sim.mat, threshold = 0.9,
   correction.for.chance = "estimate", N = 1e4, impute.na = NULL) {
-  BBmisc::requirePackages(c("igraph"), why = "stabilityIntersectionMBM",
-    default.method = "load")
+  requireNamespace("igraph")
   stability(features = features, measure = "intersection.mbm",
     sim.mat = sim.mat, threshold = threshold,
     correction.for.chance = correction.for.chance,
@@ -109,6 +98,10 @@ stabilityIntersectionMBM = function(features, sim.mat, threshold = 0.9,
 #' \deqn{I(V_i, V_j) = |V_i \cap V_j| + GMBM(V_i \backslash V_j, V_j \backslash V_i).}
 #' \eqn{GMBM(V_i \backslash V_j, V_j \backslash V_i)} denotes a greedy approximation
 #' of \eqn{MBM(V_i \backslash V_j, V_j \backslash V_i)}, see \link{stabilityIntersectionMBM}.
+#' @references
+#' `r tools::toRd(bibentries["Bommert2020"])`
+#' @encoding UTF-8
+#' @md
 #' @examples
 #' feats = list(1:3, 1:4, 1:5)
 #' mat = 0.92 ^ abs(outer(1:10, 1:10, "-"))
@@ -131,6 +124,10 @@ stabilityIntersectionGreedy = function(features, sim.mat, threshold = 0.9,
 #' with \deqn{I(V_i, V_j) = |V_i \cap V_j| + \min (C(V_i, V_j), C(V_j, V_i))} and
 #' \deqn{C(V_k, V_l) = |\{x \in  V_k \backslash V_l : \exists y \in
 #' V_l \backslash V_k \ with \ Similarity (x,y) \geq threshold \}|.}
+#' @references
+#' `r tools::toRd(bibentries["Bommert2020"])`
+#' @encoding UTF-8
+#' @md
 #' @examples
 #' feats = list(1:3, 1:4, 1:5)
 #' mat = 0.92 ^ abs(outer(1:10, 1:10, "-"))
@@ -154,6 +151,10 @@ stabilityIntersectionCount = function(features, sim.mat, threshold = 0.9,
 #' \deqn{C(V_k, V_l) = \sum_{x \in V_k \backslash V_l : |G^{kl}_x| > 0}
 #' \frac{1}{|G^{kl}_x|} \sum_{y \in G^{kl}_x} \ Similarity (x,y)} and
 #' \deqn{G^{kl}_x = \{y \in V_l \backslash V_k: \ Similarity (x, y) \geq threshold \}.}
+#' @references
+#' `r tools::toRd(bibentries["Bommert2020"])`
+#' @encoding UTF-8
+#' @md
 #' @examples
 #' feats = list(1:3, 1:4, 1:5)
 #' mat = 0.92 ^ abs(outer(1:10, 1:10, "-"))
@@ -165,3 +166,33 @@ stabilityIntersectionMean = function(features, sim.mat, threshold = 0.9,
     correction.for.chance = correction.for.chance,
     N = N, impute.na = impute.na)
 }
+
+#' @export
+#' @title Stability Measure Sechidis
+#' @inherit stabilityDocumentation
+#' @inherit uncorrectedDocumentation
+#' @details The stability measure is defined as
+#' \deqn{1 - \frac{trace(CS)}{trace(C \Sigma)}} with (\eqn{p \times p})-matrices
+#' \deqn{(S)_{ij} = \frac{m}{m-1}\left(\frac{h_{ij}}{m} - \frac{h_i}{m} \frac{h_j}{m}\right)} and
+#' \deqn{(\Sigma)_{ii} = \frac{q}{mp} \left(1 - \frac{q}{mp}\right),}
+#' \deqn{(\Sigma)_{ij} = \frac{\frac{1}{m} \sum_{i=1}^{m} |V_i|^2 - \frac{q}{m}}{p^2 - p} - \frac{q^2}{m^2 p^2}, i \neq j.}
+#' The matrix \eqn{C} is created from matrix \code{sim.mat} by setting all values of \code{sim.mat} that are smaller
+#' than \code{threshold} to 0. If you want to \eqn{C} to be equal to \code{sim.mat}, use \code{threshold = 0}.
+#' @note This stability measure is not corrected for chance.
+#' Unlike for the other stability measures in this R package, that are not corrected for chance,
+#' for \code{stabilitySechidis}, no \code{correction.for.chance} can be applied.
+#' This is because for \code{stabilitySechidis}, no finite upper bound is known at the moment,
+#' see \link{listStabilityMeasures}.
+#' @references
+#' `r tools::toRd(bibentries["Sechidis2020"])`
+#' @encoding UTF-8
+#' @md
+#' @examples
+#' feats = list(1:3, 1:4, 1:5)
+#' mat = 0.92 ^ abs(outer(1:10, 1:10, "-"))
+#' stabilitySechidis(features = feats, sim.mat = mat)
+stabilitySechidis = function(features, sim.mat, threshold = 0.9, impute.na = NULL) {
+  stability(features = features, measure = "sechidis",
+    sim.mat = sim.mat, threshold = threshold,
+    correction.for.chance = "none", impute.na = impute.na)
+}
